@@ -374,6 +374,8 @@ class Transformer(nn.Module):
     ):
         super().__init__()
         assert not (cross_attend and cond_as_self_attn_prefix)
+        self.dim_context = default(dim_context, dim)
+
         self.cond_as_self_attn_prefix = cond_as_self_attn_prefix
 
         self.grad_shrink = partial(grad_shrink, alpha = grad_shrink_alpha)
@@ -399,6 +401,7 @@ class Transformer(nn.Module):
         context_mask = None
     ):
         assert not (self.cond_as_self_attn_prefix and not exists(context))
+        assert not (exists(context) and context.shape[-1] != self.dim_context), f'you had specified a conditioning dimension of {self.dim_context}, yet what was received by the transformer has dimension of {context.shape[-1]}'
 
         n, device = x.shape[1], x.device
 
@@ -1259,6 +1262,11 @@ class CoarseTransformerWrapper(nn.Module):
         coarse_token_len = coarse_token_ids.shape[-1]
         self_attn_mask = F.pad(self_attn_mask, (1, coarse_token_len + 1), value = True) # attend to semantic bos and all coarse tokens
 
+        # forgetful causal mask - structured dropout
+
+        if self.mask_prob > 0 and self.training:
+            self_attn_mask &= generate_mask_with_prob(self_attn_mask.shape, self.mask_prob, device = self_attn_mask.device)
+
         semantic_logits, coarse_logits = self.transformer(
             semantic_token_ids = semantic_token_ids,
             coarse_token_ids = coarse_token_ids,
@@ -1268,10 +1276,6 @@ class CoarseTransformerWrapper(nn.Module):
             **kwargs
         )
 
-        # forgetful causal mask - structured dropout
-
-        if self.mask_prob > 0 and self.training:
-            self_attn_mask &= generate_mask_with_prob(self_attn_mask.shape, self.mask_prob, device = self_attn_mask.device)
 
         # whether to early return the logits
 
@@ -1479,6 +1483,11 @@ class FineTransformerWrapper(nn.Module):
         fine_token_seq_len = fine_token_ids.shape[-1]
         self_attn_mask = F.pad(self_attn_mask, (1, fine_token_seq_len + 1), value = True)
 
+        # forgetful causal mask - structured dropout
+
+        if self.mask_prob > 0 and self.training:
+            self_attn_mask &= generate_mask_with_prob(self_attn_mask.shape, self.mask_prob, device = self_attn_mask.device)
+
         coarse_logits, fine_logits = self.transformer(
             coarse_token_ids = coarse_token_ids,
             fine_token_ids = fine_token_ids,
@@ -1488,11 +1497,6 @@ class FineTransformerWrapper(nn.Module):
             **kwargs
         )
 
-        # forgetful causal mask - structured dropout
-
-        if self.mask_prob > 0 and self.training:
-            self_attn_mask &= generate_mask_with_prob(self_attn_mask.shape, self.mask_prob, device = self_attn_mask.device)
-
         # early return the logits
 
         if not return_loss:
